Mixer
#####

Mixer is simply application for generate instances of Django or SQLAlchemy models. It's useful for testing or fixtures replacement.

Mixer supports:

    - Django_;
    - SQLAlchemy_;
    - Flask-SqlAlchemy (only for python 2.6, 2.7);

.. image:: https://secure.travis-ci.org/klen.png?branch=develop
    :target: http://travis-ci.org/klen/mixer
    :alt: Build Status

.. contents::


Requirements
=============

- python (2.6, 2.7, 3.2, 3.3)
- Django (1.4, 1.5) for django ORM suport;
- SQLAlchemy for SQLAlchemy ORM suport;
- Flask-SQLALchemy for SQLAlchemy ORM suport and integration as Flask application;


Installation
=============

**Mixer** should be installed using pip: ::

    pip install mixer


Usage
=====


Bug tracker
===========

If you have any suggestions, bug reports or
annoyances please report them to the issue tracker
at https://github.com/horneds/mixer/issues


Contributing
============

Development of starter happens at github: https://github.com/horneds/mixer


Contributors
=============

* horneds_ (horneds)


License
=======

Licensed under a `BSD license`_.


.. _BSD license: http://www.linfo.org/bsdlicense.html
.. _horneds: http://klen.github.io
.. _SQLAlchemy: http://www.sqlalchemy.org/
.. _Flask: http://flask.pocoo.org/
.. _Django: http://djangoproject.org/
